window.Gleam.initSearch([{"doc":"gleam_json","title":"gleam_json","content":"# json 🐑\n\nWork with JSON in Gleam!\n\n## Installation\n\nErlang/OTP 27.0 or higher is required when targeting Erlang.\nTo use earlier versions of Erlang/OTP use version 1.0.1 of\nthis package.\n\nAdd this package to your Gleam project.\n\n```shell\n# Erlang version &lt;= OTP26\ngleam add gleam_json@1\n\n# Erlang version &gt;= OTP27\ngleam add gleam_json@2\n```\n\n## Encoding\n\n```gleam\nimport myapp.{type Cat}\nimport gleam/json\n\npub fn cat_to_json(cat: Cat) -&gt; String {\n  json.object([\n    #(&quot;name&quot;, json.string(cat.name)),\n    #(&quot;lives&quot;, json.int(cat.lives)),\n    #(&quot;flaws&quot;, json.null()),\n    #(&quot;nicknames&quot;, json.array(cat.nicknames, of: json.string)),\n  ])\n  |&gt; json.to_string\n}\n```\n\n## Parsing\n\nJSON is parsed into a `Dynamic` value which can be decoded using the\n`gleam/dynamic/decode` module from the Gleam standard library.\n\n```gleam\nimport myapp.{Cat}\nimport gleam/json\nimport gleam/dynamic/decode\n\npub fn cat_from_json(json_string: String) -&gt; Result(Cat, json.DecodeError) {\n  let cat_decoder = {\n    use name &lt;- decode.field(&quot;name&quot;, decode.string)\n    use lives &lt;- decode.field(&quot;lives&quot;, decode.int)\n    use nicknames &lt;- decode.field(&quot;nicknames&quot;, decode.list(decode.string))\n    decode.success(Cat(name:, lives:, nicknames:))\n  }\n  json.parse(from: json_string, using: cat_decoder)\n}\n```\n","url":"index.html"},{"doc":"gleam/json","title":"DecodeError","content":"pub type DecodeError {\n  UnexpectedEndOfInput\n  UnexpectedByte(String)\n  UnexpectedSequence(String)\n  UnexpectedFormat(List(dynamic.DecodeError))\n  UnableToDecode(List(decode.DecodeError))\n}\n\nUnexpectedEndOfInput\n\n\nUnexpectedByte(String)\n\n\nUnexpectedSequence(String)\n\n\nUnexpectedFormat(List(dynamic.DecodeError))\n\n\nUnableToDecode(List(decode.DecodeError))\n\n\nSynonyms:\ngleam/json.DecodeError\ngleam/json DecodeError","url":"gleam/json.html#DecodeError"},{"doc":"gleam/json","title":"Json","content":"pub type Json\n\n\nSynonyms:\ngleam/json.Json\ngleam/json Json","url":"gleam/json.html#Json"},{"doc":"gleam/json","title":"array","content":"pub fn array(\n  from entries: List(a),\n  of inner_type: fn(a) -&gt; Json,\n) -&gt; Json\n Encode a list into a JSON array.\n\n ## Examples\n\n \n &gt; to_string(array([1, 2, 3], of: int))\n &quot;[1, 2, 3]&quot;\n \n\nSynonyms:\ngleam/json.array\ngleam/json array","url":"gleam/json.html#array"},{"doc":"gleam/json","title":"bool","content":"pub fn bool(input: Bool) -&gt; Json\n Encode a bool into JSON.\n\n ## Examples\n\n \n &gt; to_string(bool(False))\n &quot;false&quot;\n \n\nSynonyms:\ngleam/json.bool\ngleam/json bool","url":"gleam/json.html#bool"},{"doc":"gleam/json","title":"decode","content":"pub fn decode(\n  from json: String,\n  using decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(a, gleam/json.DecodeError)\n The same as `parse`, but using the old `gleam/dynamic` decoder API.\n\nSynonyms:\ngleam/json.decode\ngleam/json decode","url":"gleam/json.html#decode"},{"doc":"gleam/json","title":"decode_bits","content":"pub fn decode_bits(\n  from json: BitArray,\n  using decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(a, gleam/json.DecodeError)\n The same as `parse_bits`, but using the old `gleam/dynamic` decoder API.\n\nSynonyms:\ngleam/json.decode_bits\ngleam/json decode_bits","url":"gleam/json.html#decode_bits"},{"doc":"gleam/json","title":"dict","content":"pub fn dict(\n  dict: Dict(a, b),\n  keys: fn(a) -&gt; String,\n  values: fn(b) -&gt; Json,\n) -&gt; Json\n Encode a Dict into a JSON object using the supplied functions to encode\n the keys and the values respectively.\n\n ## Examples\n\n \n &gt; to_string(dict(dict.from_list([ #(3, 3.0), #(4, 4.0)]), int.to_string, float)\n &quot;{\\&quot;3\\&quot;: 3.0, \\&quot;4\\&quot;: 4.0}&quot;\n \n\nSynonyms:\ngleam/json.dict\ngleam/json dict","url":"gleam/json.html#dict"},{"doc":"gleam/json","title":"float","content":"pub fn float(input: Float) -&gt; Json\n Encode a float into JSON.\n\n ## Examples\n\n \n &gt; to_string(float(4.7))\n &quot;4.7&quot;\n \n\nSynonyms:\ngleam/json.float\ngleam/json float","url":"gleam/json.html#float"},{"doc":"gleam/json","title":"int","content":"pub fn int(input: Int) -&gt; Json\n Encode an int into JSON.\n\n ## Examples\n\n \n &gt; to_string(int(50))\n &quot;50&quot;\n \n\nSynonyms:\ngleam/json.int\ngleam/json int","url":"gleam/json.html#int"},{"doc":"gleam/json","title":"null","content":"pub fn null() -&gt; Json\n The JSON value null.\n\n ## Examples\n\n \n &gt; to_string(null())\n &quot;null&quot;\n \n\nSynonyms:\ngleam/json.null\ngleam/json null","url":"gleam/json.html#null"},{"doc":"gleam/json","title":"nullable","content":"pub fn nullable(\n  from input: Option(a),\n  of inner_type: fn(a) -&gt; Json,\n) -&gt; Json\n Encode an optional value into JSON, using null if it is the `None` variant.\n\n ## Examples\n\n \n &gt; to_string(nullable(Some(50), of: int))\n &quot;50&quot;\n \n\n \n &gt; to_string(nullable(None, of: int))\n &quot;null&quot;\n \n\nSynonyms:\ngleam/json.nullable\ngleam/json nullable","url":"gleam/json.html#nullable"},{"doc":"gleam/json","title":"object","content":"pub fn object(entries: List(#(String, Json))) -&gt; Json\n Encode a list of key-value pairs into a JSON object.\n\n ## Examples\n\n \n &gt; to_string(object([\n   #(&quot;game&quot;, string(&quot;Pac-Man&quot;)),\n   #(&quot;score&quot;, int(3333360)),\n ]))\n &quot;{\\&quot;game\\&quot;:\\&quot;Pac-Mac\\&quot;,\\&quot;score\\&quot;:3333360}&quot;\n \n\nSynonyms:\ngleam/json.object\ngleam/json object","url":"gleam/json.html#object"},{"doc":"gleam/json","title":"parse","content":"pub fn parse(\n  from json: String,\n  using decoder: Decoder(a),\n) -&gt; Result(a, DecodeError)\n Decode a JSON string into dynamically typed data which can be decoded into\n typed data with the `gleam/dynamic` module.\n\n ## Examples\n\n \n &gt; decode(&quot;[1,2,3]&quot;, decode.list(of: decode.int))\n Ok([1, 2, 3])\n \n\n \n &gt; decode(&quot;[&quot;, decode.list(of: decode.int))\n Error(UnexpectedEndOfInput)\n \n\n \n &gt; decode(&quot;1&quot;, decode.string)\n Error(UnableToDecode([decode.DecodeError(&quot;String&quot;, &quot;Int&quot;, [])]))\n \n\nSynonyms:\ngleam/json.parse\ngleam/json parse","url":"gleam/json.html#parse"},{"doc":"gleam/json","title":"parse_bits","content":"pub fn parse_bits(\n  from json: BitArray,\n  using decoder: Decoder(a),\n) -&gt; Result(a, DecodeError)\n Decode a JSON bit string into dynamically typed data which can be decoded\n into typed data with the `gleam/dynamic` module.\n\n ## Examples\n\n \n &gt; decode_bits(&lt;&lt;&quot;[1,2,3]&quot;&gt;&gt;, decode.list(of: decode.int))\n Ok([1, 2, 3])\n \n\n \n &gt; decode_bits(&lt;&lt;&quot;[&quot;&gt;&gt;, decode.list(of: decode.int))\n Error(UnexpectedEndOfInput)\n \n\n \n &gt; decode_bits(&quot;&lt;&lt;1&quot;&gt;&gt;, decode.string)\n Error(UnexpectedFormat([decode.DecodeError(&quot;String&quot;, &quot;Int&quot;, [])]))\n \n\nSynonyms:\ngleam/json.parse_bits\ngleam/json parse_bits","url":"gleam/json.html#parse_bits"},{"doc":"gleam/json","title":"preprocessed_array","content":"pub fn preprocessed_array(from: List(Json)) -&gt; Json\n Encode a list of JSON values into a JSON array.\n\n ## Examples\n\n \n &gt; to_string(preprocessed_array([int(1), float(2.0), string(&quot;3&quot;)]))\n &quot;[1, 2.0, \\&quot;3\\&quot;]&quot;\n \n\nSynonyms:\ngleam/json.preprocessed_array\ngleam/json preprocessed_array","url":"gleam/json.html#preprocessed_array"},{"doc":"gleam/json","title":"string","content":"pub fn string(input: String) -&gt; Json\n Encode a string into JSON, using normal JSON escaping.\n\n ## Examples\n\n \n &gt; to_string(string(&quot;Hello!&quot;))\n &quot;\\&quot;Hello!\\&quot;&quot;\n \n\nSynonyms:\ngleam/json.string\ngleam/json string","url":"gleam/json.html#string"},{"doc":"gleam/json","title":"to_string","content":"pub fn to_string(json: Json) -&gt; String\n Convert a JSON value into a string.\n\n Where possible prefer the `to_string_tree` function as it is faster than\n this function, and BEAM VM IO is optimised for sending `StringTree` data.\n\n ## Examples\n\n \n &gt; to_string(array([1, 2, 3], of: int))\n &quot;[1,2,3]&quot;\n \n\nSynonyms:\ngleam/json.to_string\ngleam/json to_string","url":"gleam/json.html#to_string"},{"doc":"gleam/json","title":"to_string_builder","content":"pub fn to_string_builder(json: Json) -&gt; StringTree\n Convert a JSON value into a string builder.\n\n Where possible prefer this function to the `to_string` function as it is\n slower than this function, and BEAM VM IO is optimised for sending\n `StringTree` data.\n\n ## Examples\n\n \n &gt; to_string_builder(array([1, 2, 3], of: int))\n string_builder.from_string(&quot;[1,2,3]&quot;)\n \n\nSynonyms:\ngleam/json.to_string_builder\ngleam/json to_string_builder","url":"gleam/json.html#to_string_builder"},{"doc":"gleam/json","title":"to_string_tree","content":"pub fn to_string_tree(json: Json) -&gt; StringTree\n Convert a JSON value into a string tree.\n\n Where possible prefer this function to the `to_string` function as it is\n slower than this function, and BEAM VM IO is optimised for sending\n `StringTree` data.\n\n ## Examples\n\n \n &gt; to_string_tree(array([1, 2, 3], of: int))\n string_tree.from_string(&quot;[1,2,3]&quot;)\n \n\nSynonyms:\ngleam/json.to_string_tree\ngleam/json to_string_tree","url":"gleam/json.html#to_string_tree"},{"doc":"gleam/json","title":"gleam/json","content":"","url":"gleam/json.html"}]);